# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to tweak the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# Pick up the right dictionary for the spell check
%if 0%{?fedora} > 8 || 0%{?rhel} > 5
%global speller hunspell
%else
%global speller aspell
%endif

Name:		perl-Symbol-Util
Version:	0.0203
Release:	12.%{__distinit}%{__distvers}
Summary:	Additional utilities for Perl symbols manipulation
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Symbol-Util/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/Symbol-Util-%{version}.tar.gz
Source1:	C0B10A5B.pub
Patch0:		Symbol-Util-0.0203-Critic.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg
BuildRequires:	make
BuildRequires:	patch
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test::Harness)
BuildRequires:	perl(Test::More)
# Release Tests
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), %{speller}-en
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Carp)

%description
This module provides a set of additional functions useful for Perl symbols
manipulation.

%prep
%setup -q -c -n Symbol-Util

# Copy up documentation for convenience with %%doc
cp -a Symbol-Util-%{version}/{Changes,examples,LICENSE,README} .

# Clean up permissions where necessary
chmod -c -x,u+w examples/*

# Create a GPG directory for testing, to avoid using ~/.gnupg
mkdir --mode=0700 gnupghome
GNUPGHOME=$(pwd)/gnupghome gpg --import %{SOURCE1}

%build
cd Symbol-Util-%{version}
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}
make -C Symbol-Util-%{version} pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
export GNUPGHOME=$(pwd)/gnupghome
cd Symbol-Util-%{version}

# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
RELEASE_TESTS="$(echo xt/*.t)"

# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"

# Don't run the spelling test yet as we need to work around a hunspell issue
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/pod_spell.t||')"

# Don't run the perlcritic test yet as we need to patch the code
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"

# Changes test needs tweaking if we don't have Test::More ≥ 0.88,
# but don't do it yet as it would cause the signature test to fail
%if %{old_test_more}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/check_changes.t||')"
%endif

make test TEST_FILES="$RELEASE_TESTS"

# Now try the Changes test if we didn't run it before
%if %{old_test_more}
sed -e 's|^use Test::CheckChanges;|use Test::More tests => 1;\n&|' xt/check_changes.t > xt/check_changes_compat.t
make test TEST_FILES=xt/check_changes_compat.t
rm xt/check_changes_compat.t
%endif

# Patch the code to turn off one check before running the perlcritic test
patch -p0 < %{P:0}
make test TEST_FILES=xt/perlcritic.t
patch -p0 -R < %{P:0}

# Fix the POD Spell test to work around hunspell not recognising "doesn't" and run it
# (affects hunspell prior to Fedora 14/RHEL-6)
mv xt/pod_spellrc xt/pod_spellrc.orig
(
	cat xt/pod_spellrc.orig
	echo "doesn"
) > xt/pod_spellrc
make test TEST_FILES=xt/pod_spell.t
mv xt/pod_spellrc.orig xt/pod_spellrc

cd -

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes examples/ README
%{perl_vendorlib}/Symbol/
%{_mandir}/man3/Symbol::Util.3*

%changelog
* Tue Sep 27 2016 Paul Howarth <paul@city-fan.org> - 0.0203-12
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.0203-8
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> - 0.0203-5
- Perl 5.18 rebuild

* Sun Jun 23 2013 Paul Howarth <paul@city-fan.org> - 0.0203-3
- Tweak the perlcritic test, which has discovered something to moan about

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 0.0203-2
- BR: perl(Cwd), perl(File::Spec) and perl(Test::More)
- Specify version requirements for Test::Pod and Test::Pod::Coverage

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> - 0.0203-1
- Update to 0.0203
  - Compiles cleanly with Perl 5.14: defined(%%hash) and defined(@array) are
    deprecated (CPAN RT#75763)
  - Minor changes in POD
- BR:/R: perl(Carp)
- Sample documentation eg/ directory renamed to examples/
- Don't need to remove empty directories from buildroot
- Don't need to work around MYMETA.* generation
- Add workaround for some versions of hunspell not handling "doesn't" properly
- Drop compatibility with distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Never need to BR: aspell-en-gb
  - Test::Perl::Critic always available

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> - 0.0202-8
- Rebuild for perl 5.14.1 in Rawhide
- Work around signature test failing on recent distributions due to presence
  of MYMETA.yml
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.0202-7
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0202-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.0202-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue Jun 22 2010 Petr Pisar <ppisar@redhat.com> - 0.0202-4
- Rebuild against perl-5.12

* Tue May 04 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-3
- Remove perl from BuildRequires

* Mon May 03 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-2
- Add missing BuildRequires

* Mon Apr 12 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-1
- Specfile autogenerated by cpanspec 1.78
